@@ -210,13 +210,15 @@ REFERENCES:
 #                  https://www.gnu.org/licenses/
 # ****************************************************************************
 
-from sage.functions.other import sqrt
+from sage.misc.functional import sqrt
 from sage.functions.log import exp
 from sage.functions.hyperbolic import sinh, cosh
 from sage.functions.trig import sin, cos
 from sage.libs.mpmath import utils as mpmath_utils
 from sage.misc.latex import latex
-from sage.rings.all import Integer, ZZ, QQ
+from sage.rings.integer import Integer
+from sage.rings.integer_ring import ZZ
+from sage.rings.rational_field import QQ
 from sage.structure.element import get_coercion_model
 from sage.symbolic.constants import pi
 from sage.symbolic.ring import SR
@@ -332,7 +334,8 @@ class Function_Bessel_J(BuiltinFunction):
             besselj(x, x)
         """
         BuiltinFunction.__init__(self, 'bessel_J', nargs=2,
-                                 conversions=dict(mathematica='BesselJ',
+                                 conversions=dict(maple='BesselJ',
+                                                  mathematica='BesselJ',
                                                   maxima='bessel_j',
                                                   sympy='besselj',
                                                   fricas='besselJ',
@@ -361,15 +364,15 @@ class Function_Bessel_J(BuiltinFunction):
         from sage.rings.infinity import unsigned_infinity
         if not isinstance(x, Expression) and x == 0:
             if n == 0:
-                return ZZ(1)
+                return ZZ.one()
             elif n.real() > 0 or n in ZZ:
-                return ZZ(0)
+                return ZZ.zero()
             elif n.real() < 0:
                 return unsigned_infinity
-        if n == QQ(1)/2:
-            return sqrt(2/pi/x) * sin(x)
-        elif n == QQ(-1)/2:
-            return sqrt(2/pi/x) * cos(x)
+        if n == QQ((1, 2)):
+            return sqrt(2 / pi / x) * sin(x)
+        elif n == QQ((-1, 2)):
+            return sqrt(2 / pi / x) * cos(x)
 
     def _evalf_(self, n, x, parent=None, algorithm=None):
         """
@@ -437,6 +440,7 @@ class Function_Bessel_J(BuiltinFunction):
         """
         return r"J_{%s}(%s)" % (latex(n), latex(z))
 
+
 bessel_J = Function_Bessel_J()
 
 
@@ -549,7 +553,8 @@ class Function_Bessel_Y(BuiltinFunction):
             bessely(x, x)
         """
         BuiltinFunction.__init__(self, 'bessel_Y', nargs=2,
-                                 conversions=dict(mathematica='BesselY',
+                                 conversions=dict(maple='BesselY',
+                                                  mathematica='BesselY',
                                                   maxima='bessel_y',
                                                   sympy='bessely',
                                                   fricas='besselY',
@@ -579,10 +584,10 @@ class Function_Bessel_Y(BuiltinFunction):
                 return -infinity
             elif n.real() > 0 or n.real() < 0:
                 return unsigned_infinity
-        if n == QQ(1)/2:
-            return -sqrt(2/pi/x) * cos(x)
-        elif n == QQ(-1)/2:
-            return sqrt(2/pi/x) * sin(x)
+        if n == QQ((1, 2)):
+            return -sqrt(2 / pi / x) * cos(x)
+        elif n == QQ((-1, 2)):
+            return sqrt(2 / pi / x) * sin(x)
 
     def _evalf_(self, n, x, parent=None, algorithm=None):
         """
@@ -649,6 +654,7 @@ class Function_Bessel_Y(BuiltinFunction):
         """
         return r"Y_{%s}(%s)" % (latex(n), latex(z))
 
+
 bessel_Y = Function_Bessel_Y()
 
 
@@ -755,7 +761,8 @@ class Function_Bessel_I(BuiltinFunction):
             besseli(x, x)
         """
         BuiltinFunction.__init__(self, 'bessel_I', nargs=2,
-                                 conversions=dict(mathematica='BesselI',
+                                 conversions=dict(maple='BesselI',
+                                                  mathematica='BesselI',
                                                   maxima='bessel_i',
                                                   sympy='besseli',
                                                   fricas='besselI'))
@@ -783,17 +790,16 @@ class Function_Bessel_I(BuiltinFunction):
         from sage.rings.infinity import unsigned_infinity
         if not isinstance(x, Expression) and x == 0:
             if n == 0:
-                return ZZ(1)
+                return ZZ.one()
             elif n.real() > 0 or n in ZZ:
-                return ZZ(0)
+                return ZZ.zero()
             elif n.real() < 0:
                 return unsigned_infinity
-        if n == QQ(1)/2:
+        if n == QQ((1, 2)):
             return sqrt(2 / (pi * x)) * sinh(x)
-        elif n == -QQ(1)/2:
+        elif n == QQ((-1, 2)):
             return sqrt(2 / (pi * x)) * cosh(x)
 
-
     def _evalf_(self, n, x, parent=None, algorithm=None):
         """
         EXAMPLES::
@@ -838,6 +844,7 @@ class Function_Bessel_I(BuiltinFunction):
         """
         return r"I_{%s}(%s)" % (latex(n), latex(z))
 
+
 bessel_I = Function_Bessel_I()
 
 
@@ -955,7 +962,8 @@ class Function_Bessel_K(BuiltinFunction):
             besselk(x, x)
         """
         BuiltinFunction.__init__(self, 'bessel_K', nargs=2,
-                                 conversions=dict(mathematica='BesselK',
+                                 conversions=dict(maple='BesselK',
+                                                  mathematica='BesselK',
                                                   maxima='bessel_k',
                                                   sympy='besselk',
                                                   fricas='besselK'))
@@ -983,10 +991,9 @@ class Function_Bessel_K(BuiltinFunction):
                 return infinity
             elif n.real() > 0 or n.real() < 0:
                 return unsigned_infinity
-        if n == QQ(1)/2 or n == -QQ(1)/2 and x > 0:
+        if n == QQ((1, 2)) or n == QQ((-1, 2)) and x > 0:
             return sqrt(pi / 2) * exp(-x) * x ** (-Integer(1) / Integer(2))
 
-
     def _evalf_(self, n, x, parent=None, algorithm=None):
         """
         EXAMPLES::
@@ -1032,6 +1039,7 @@ class Function_Bessel_K(BuiltinFunction):
         """
         return r"K_{%s}(%s)" % (latex(n), latex(z))
 
+
 bessel_K = Function_Bessel_K()
 
 
@@ -1112,9 +1120,9 @@ def Bessel(*args, **kwds):
         sage: x,y = var('x,y')
         sage: f = maxima(Bessel(typ='K')(x,y))
         sage: f.derivative('_SAGE_VAR_x')
-        (%pi*csc(%pi*_SAGE_VAR_x)*('diff(bessel_i(-_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1)-'diff(bessel_i(_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1)))/2-%pi*bessel_k(_SAGE_VAR_x,_SAGE_VAR_y)*cot(%pi*_SAGE_VAR_x)
+        (%pi*csc(%pi*_SAGE_VAR_x) *('diff(bessel_i(-_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1) -'diff(bessel_i(_SAGE_VAR_x,_SAGE_VAR_y),_SAGE_VAR_x,1))) /2 -%pi*bessel_k(_SAGE_VAR_x,_SAGE_VAR_y)*cot(%pi*_SAGE_VAR_x)
         sage: f.derivative('_SAGE_VAR_y')
-        -(bessel_k(_SAGE_VAR_x+1,_SAGE_VAR_y)+bessel_k(_SAGE_VAR_x-1,_SAGE_VAR_y))/2
+        -(bessel_k(_SAGE_VAR_x+1,_SAGE_VAR_y)+bessel_k(_SAGE_VAR_x-1, _SAGE_VAR_y))/2
 
     Compute the particular solution to Bessel's Differential Equation that
     satisfies `y(1) = 1` and `y'(1) = 1`, then verify the initial conditions
@@ -1246,7 +1254,8 @@ class Function_Struve_H(BuiltinFunction):
                                  conversions=dict(maple='StruveH',
                                                   mathematica='StruveH',
                                                   maxima='struve_h',
-                                                  fricas='struveH'))
+                                                  fricas='struveH',
+                                                  sympy='struveh'))
 
     def _eval_(self, a, z):
         """
@@ -1267,21 +1276,19 @@ class Function_Struve_H(BuiltinFunction):
             sage: struve_H(-3/2,x)
             -bessel_J(3/2, x)
         """
-        from sage.symbolic.ring import SR
         if z.is_zero() \
                 and (SR(a).is_numeric() or SR(a).is_constant()) \
                 and a.real() >= -1:
-                return ZZ(0)
-        if a == -Integer(1)/2:
+            return ZZ.zero()
+        if a == QQ((-1, 2)):
             from sage.functions.trig import sin
-            return sqrt(2/(pi*z)) * sin(z)
-        if a == Integer(1)/2:
+            return sqrt(2 / (pi * z)) * sin(z)
+        if a == QQ((1, 2)):
             from sage.functions.trig import cos
-            return sqrt(2/(pi*z)) * (1-cos(z))
-        if a < 0 and not SR(a).is_integer() and SR(2*a).is_integer():
-            from sage.rings.rational_field import QQ
-            n = (a*(-2) - 1)/2
-            return Integer(-1)**n * bessel_J(n+QQ(1)/2, z)
+            return sqrt(2 / (pi * z)) * (1 - cos(z))
+        if a < 0 and not SR(a).is_integer() and SR(2 * a).is_integer():
+            n = (a * (-2) - 1) / 2
+            return Integer(-1)**n * bessel_J(n + QQ((1, 2)), z)
 
     def _evalf_(self, a, z, parent=None, algorithm=None):
         """
@@ -1307,7 +1314,7 @@ class Function_Struve_H(BuiltinFunction):
 
         from .gamma import gamma
         from .other import sqrt
-        return (z**a/(sqrt(pi)*2**a*gamma(a+Integer(3)/Integer(2)))-struve_H(a+1,z)+struve_H(a-1,z))/2
+        return (z**a / (sqrt(pi) * 2**a * gamma(a + Integer(3) / Integer(2))) - struve_H(a + 1, z) + struve_H(a - 1, z)) / 2
 
     def _print_latex_(self, a, z):
         """
@@ -1318,8 +1325,10 @@ class Function_Struve_H(BuiltinFunction):
         """
         return r"H_{{%s}}({%s})" % (a, z)
 
+
 struve_H = Function_Struve_H()
 
+
 class Function_Struve_L(BuiltinFunction):
     r"""
     The modified Struve functions.
@@ -1361,7 +1370,8 @@ class Function_Struve_L(BuiltinFunction):
                                  conversions=dict(maple='StruveL',
                                                   mathematica='StruveL',
                                                   maxima='struve_l',
-                                                  fricas='struveL'))
+                                                  fricas='struveL',
+                                                  sympy='struvel'))
 
     def _eval_(self, a, z):
         """
@@ -1382,21 +1392,19 @@ class Function_Struve_L(BuiltinFunction):
             sage: struve_L(-3/2,x)
             -bessel_I(3/2, x)
         """
-        from sage.symbolic.ring import SR
         if z.is_zero() \
                 and (SR(a).is_numeric() or SR(a).is_constant()) \
                 and a.real() >= -1:
-                return ZZ(0)
-        if a == -Integer(1)/2:
+            return ZZ.zero()
+        if a == -Integer(1) / 2:
             from sage.functions.hyperbolic import sinh
-            return sqrt(2/(pi*z)) * sinh(z)
-        if a == Integer(1)/2:
+            return sqrt(2 / (pi * z)) * sinh(z)
+        if a == Integer(1) / 2:
             from sage.functions.hyperbolic import cosh
-            return sqrt(2/(pi*z)) * (cosh(z)-1)
-        if a < 0 and not SR(a).is_integer() and SR(2*a).is_integer():
-            from sage.rings.rational_field import QQ
-            n = (a*(-2) - 1)/2
-            return Integer(-1)**n * bessel_I(n+QQ(1)/2, z)
+            return sqrt(2 / (pi * z)) * (cosh(z) - 1)
+        if a < 0 and not SR(a).is_integer() and SR(2 * a).is_integer():
+            n = (a * (-2) - 1) / 2
+            return Integer(-1)**n * bessel_I(n + QQ((1, 2)), z)
 
     def _evalf_(self, a, z, parent=None, algorithm=None):
         """
@@ -1422,7 +1430,7 @@ class Function_Struve_L(BuiltinFunction):
 
         from .gamma import gamma
         from .other import sqrt
-        return (z**a/(sqrt(pi)*2**a*gamma(a+Integer(3)/Integer(2)))-struve_L(a+1,z)+struve_L(a-1,z))/2
+        return (z**a / (sqrt(pi) * 2**a * gamma(a + Integer(3) / Integer(2))) - struve_L(a + 1, z) + struve_L(a - 1, z)) / 2
 
     def _print_latex_(self, a, z):
         """
@@ -1431,6 +1439,7 @@ class Function_Struve_L(BuiltinFunction):
         """
         return r"L_{{%s}}({%s})" % (a, z)
 
+
 struve_L = Function_Struve_L()
 
 
@@ -1518,6 +1527,7 @@ class Function_Hankel1(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 hankel1 = Function_Hankel1()
 
 
@@ -1605,6 +1615,7 @@ class Function_Hankel2(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 hankel2 = Function_Hankel2()
 
 
@@ -1652,11 +1663,11 @@ class SphericalBesselJ(BuiltinFunction):
             sage: spherical_bessel_J(3, x)._sympy_()
             jn(3, x)
         """
+        conversions = dict(mathematica='SphericalBesselJ',
+                           maxima='spherical_bessel_j',
+                           sympy='jn')
         BuiltinFunction.__init__(self, 'spherical_bessel_J', nargs=2,
-                                 conversions=dict(mathematica=
-                                                  'SphericalBesselJ',
-                                                  maxima='spherical_bessel_j',
-                                                  sympy='jn'))
+                                 conversions=conversions)
 
     def _evalf_(self, n, z, parent, algorithm=None):
         r"""
@@ -1704,6 +1715,7 @@ class SphericalBesselJ(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 spherical_bessel_J = SphericalBesselJ()
 
 
@@ -1749,11 +1761,11 @@ class SphericalBesselY(BuiltinFunction):
             sage: spherical_bessel_Y(3, x)._sympy_()
             yn(3, x)
         """
+        conversions = dict(mathematica='SphericalBesselY',
+                           maxima='spherical_bessel_y',
+                           sympy='yn')
         BuiltinFunction.__init__(self, 'spherical_bessel_Y', nargs=2,
-                                 conversions=dict(mathematica=
-                                                  'SphericalBesselY',
-                                                  maxima='spherical_bessel_y',
-                                                  sympy='yn'))
+                                 conversions=conversions)
 
     def _evalf_(self, n, z, parent, algorithm=None):
         r"""
@@ -1803,6 +1815,7 @@ class SphericalBesselY(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 spherical_bessel_Y = SphericalBesselY()
 
 
@@ -1846,10 +1859,10 @@ class SphericalHankel1(BuiltinFunction):
             sage: spherical_hankel1
             spherical_hankel1
         """
+        conversions = dict(mathematica='SphericalHankelH1',
+                           maxima='spherical_hankel1')
         BuiltinFunction.__init__(self, 'spherical_hankel1', nargs=2,
-                                 conversions=dict(mathematica=
-                                                  'SphericalHankelH1',
-                                                  maxima='spherical_hankel1'))
+                                 conversions=conversions)
 
     def _evalf_(self, n, z, parent, algorithm=None):
         r"""
@@ -1899,6 +1912,7 @@ class SphericalHankel1(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 spherical_hankel1 = SphericalHankel1()
 
 
@@ -1947,9 +1961,8 @@ class SphericalHankel2(BuiltinFunction):
             spherical_hankel2
         """
         BuiltinFunction.__init__(self, 'spherical_hankel2', nargs=2,
-                                 conversions=dict(mathematica=
-                                                  'SphericalHankelH2',
-                                                  maxima='spherical_hankel2'))
+            conversions=dict(mathematica='SphericalHankelH2',
+                             maxima='spherical_hankel2'))
 
     def _evalf_(self, n, z, parent, algorithm=None):
         r"""
@@ -2007,6 +2020,7 @@ class SphericalHankel2(BuiltinFunction):
         else:
             raise NotImplementedError('derivative with respect to order')
 
+
 spherical_hankel2 = SphericalHankel2()
 
 
@@ -2053,4 +2067,3 @@ def spherical_bessel_f(F, n, z):
         return quotient * Fz
     finally:
         ctx.prec = prec
-
