@@ -21,6 +21,7 @@ The methods defined here appear in :mod:`sage.graphs.graph_generators`.
 from sage.graphs.graph import Graph
 from math import sin, cos, pi
 
+
 def BullGraph():
     r"""
     Return a bull graph with 5 nodes.
@@ -66,7 +67,8 @@ def BullGraph():
     the identity matrix of the same dimensions as `A`::
 
         sage: chrompoly = g.chromatic_polynomial()
-        sage: bool(expand(x * (x - 2) * (x - 1)^3) == chrompoly)
+        sage: x = chrompoly.parent()('x')
+        sage: x * (x - 2) * (x - 1)^3 == chrompoly
         True
         sage: charpoly = g.characteristic_polynomial()
         sage: M = g.adjacency_matrix(); M
@@ -77,15 +79,16 @@ def BullGraph():
         [0 0 1 0 0]
         sage: Id = identity_matrix(ZZ, M.nrows())
         sage: D = x*Id - M
-        sage: bool(D.determinant() == charpoly)
+        sage: D.determinant() == charpoly
         True
-        sage: bool(expand(x * (x^2 - x - 3) * (x^2 + x - 1)) == charpoly)
+        sage: x * (x^2 - x - 3) * (x^2 + x - 1) == charpoly
         True
     """
     edge_list = [(0, 1), (0, 2), (1, 2), (1, 3), (2, 4)]
     pos_dict = {0: (0, 0), 1: (-1, 1), 2: (1, 1), 3: (-2, 2), 4: (2, 2)}
     return Graph(edge_list, pos=pos_dict, name="Bull graph")
 
+
 def ButterflyGraph():
     r"""
     Return the butterfly graph.
@@ -130,8 +133,8 @@ def ButterflyGraph():
         3
     """
     edge_dict = {
-        0: [3,4],
-        1: [2,4],
+        0: [3, 4],
+        1: [2, 4],
         2: [4],
         3: [4]}
     pos_dict = {
@@ -221,6 +224,7 @@ def ClawGraph():
     pos_dict = {0: (0, 1), 1: (-1, 0), 2: (0, 0), 3: (1, 0)}
     return Graph(edge_list, pos=pos_dict, name="Claw graph")
 
+
 def CycleGraph(n):
     r"""
     Return a cycle graph with `n` nodes.
@@ -303,6 +307,7 @@ def CycleGraph(n):
         G.add_cycle(list(range(n)))
     return G
 
+
 def CompleteGraph(n):
     r"""
     Return a complete graph on `n` nodes.
@@ -385,9 +390,10 @@ def CompleteGraph(n):
         G.set_pos({0: (0, 0)})
     else:
         G._circle_embedding(list(range(n)), angle=pi/2)
-    G.add_edges(((i,j) for i in range(n) for j in range(i+1,n)))
+    G.add_edges(((i, j) for i in range(n) for j in range(i + 1, n)))
     return G
 
+
 def CompleteBipartiteGraph(p, q, set_position=True):
     r"""
     Return a Complete Bipartite Graph on `p + q` vertices.
@@ -514,13 +520,14 @@ def CompleteBipartiteGraph(p, q, set_position=True):
 
     return G
 
-def CompleteMultipartiteGraph(l):
+
+def CompleteMultipartiteGraph(L):
     r"""
     Return a complete multipartite graph.
 
     INPUT:
 
-    - ``l`` -- a list of integers; the respective sizes of the components
+    - ``L`` -- a list of integers; the respective sizes of the components
 
     PLOTTING: Produce a layout of the vertices so that vertices in the same
     vertex set are adjacent and clearly separated from vertices in other vertex
@@ -546,16 +553,16 @@ def CompleteMultipartiteGraph(l):
         sage: g.chromatic_number()
         3
     """
-    r = len(l)  # getting the number of partitions
-    name = "Multipartite Graph with set sizes {}".format(l)
+    r = len(L)  # getting the number of partitions
+    name = "Multipartite Graph with set sizes {}".format(L)
 
     if not r:
         g = Graph()
     elif r == 1:
-        g = Graph(l[0])
-        g._line_embedding(range(l[0]), first=(0, 0), last=(l[0], 0))
+        g = Graph(L[0])
+        g._line_embedding(range(L[0]), first=(0, 0), last=(L[0], 0))
     elif r == 2:
-        g = CompleteBipartiteGraph(l[0], l[1])
+        g = CompleteBipartiteGraph(L[0], L[1])
         g.name(name)
     else:
         # This position code gives bad results on bipartite or isolated graphs
@@ -566,16 +573,16 @@ def CompleteMultipartiteGraph(l):
         counter = 0
         positions = {}
         for i in range(r):
-            vertex_set_size = l[i] + 1
+            vertex_set_size = L[i] + 1
             for j in range(1, vertex_set_size):
                 x = points[i][0] + slopes[i][0] * j / vertex_set_size
                 y = points[i][1] + slopes[i][1] * j / vertex_set_size
                 positions[counter] = (x, y)
                 counter += 1
 
-        g = Graph(sum(l))
+        g = Graph(sum(L))
         s = 0
-        for i in l:
+        for i in L:
             g.add_clique(range(s, s + i))
             s += i
 
@@ -585,6 +592,7 @@ def CompleteMultipartiteGraph(l):
     g.name(name)
     return g
 
+
 def DiamondGraph():
     """
     Return a diamond graph with 4 nodes.
@@ -603,10 +611,11 @@ def DiamondGraph():
         sage: g = graphs.DiamondGraph()
         sage: g.show()  # long time
     """
-    pos_dict = {0:(0,1),1:(-1,0),2:(1,0),3:(0,-1)}
+    pos_dict = {0: (0, 1), 1: (-1, 0), 2: (1, 0), 3: (0, -1)}
     edges = [(0, 1), (0, 2), (1, 2), (1, 3), (2, 3)]
     return Graph(edges, pos=pos_dict, name="Diamond Graph")
 
+
 def GemGraph():
     """
     Return a gem graph with 5 nodes.
@@ -628,6 +637,7 @@ def GemGraph():
     edges = [(0, 1), (0, 2), (0, 3), (0, 4), (1, 2), (2, 3), (3, 4)]
     return Graph(edges, pos=pos_dict, name="Gem Graph")
 
+
 def ForkGraph():
     """
     Return a fork graph with 5 nodes.
@@ -649,6 +659,7 @@ def ForkGraph():
     edges = [(0, 2), (2, 3), (3, 1), (2, 4)]
     return Graph(edges, pos=pos_dict, name="Fork Graph")
 
+
 def DartGraph():
     """
     Return a dart graph with 5 nodes.
@@ -668,6 +679,7 @@ def DartGraph():
     edges = [(0, 1), (0, 2), (1, 4), (2, 4), (0, 4), (3, 4)]
     return Graph(edges, pos=pos_dict, name="Dart Graph")
 
+
 def EmptyGraph():
     """
     Return an empty graph (0 nodes and 0 edges).
@@ -706,6 +718,7 @@ def EmptyGraph():
     """
     return Graph(sparse=True)
 
+
 def ToroidalGrid2dGraph(p, q):
     r"""
     Return a toroidal 2-dimensional grid graph with `p \times q` nodes (`p` rows
@@ -729,26 +742,27 @@ def ToroidalGrid2dGraph(p, q):
         sage: tgrid.is_regular()
         True
     """
-    g = Grid2dGraph(p, q, set_positions=False)
+    g = Grid2dGraph(p, q, set_positions=True)
 
     g.add_edges([((i, 0), (i, q - 1)) for i in range(p)])
     g.add_edges([((0, i), (p - 1, i)) for i in range(q)])
 
     g.name("Toroidal 2D Grid Graph with parameters {},{}".format(p, q))
 
-    d = g.get_pos()
+    pos = g._pos
     p += 0.
     q += 0.
     uf = (p / 2) * (p / 2)
     vf = (q / 2) * (q / 2)
-    for u, v in d:
-        x, y = d[u, v]
-        x +=  0.25 * (1.0 + u * (u - p + 1) / uf)
-        y +=  0.25 * (1 + v * (v - q + 1) / vf)
-        d[u, v] = (x, y)
+    for u, v in g:
+        x, y = pos[u, v]
+        x += 0.25 * (1.0 + u * (u - p + 1) / uf)
+        y += 0.25 * (1.0 + v * (v - q + 1) / vf)
+        pos[u, v] = (x, y)
 
     return g
 
+
 def Toroidal6RegularGrid2dGraph(p, q):
     r"""
     Return a toroidal 6-regular grid.
@@ -804,6 +818,7 @@ def Toroidal6RegularGrid2dGraph(p, q):
     g.name("Toroidal Hexagonal Grid graph on {}x{} elements".format(p, q))
     return g
 
+
 def Grid2dGraph(p, q, set_positions=True):
     r"""
     Return a `2`-dimensional grid graph with `p \times q` nodes (`p` rows and
@@ -869,6 +884,7 @@ def Grid2dGraph(p, q, set_positions=True):
     G.add_edges(((i, j), (i, j + 1)) for i in range(p) for j in range(q - 1))
     return G
 
+
 def GridGraph(dim_list):
     r"""
     Return an `n`-dimensional grid graph.
@@ -910,7 +926,7 @@ def GridGraph(dim_list):
     One dimensional grids (i.e., path) have simple vertex labels::
 
         sage: g = graphs.GridGraph([5])
-        sage: g.vertices()
+        sage: g.vertices(sort=True)
         [0, 1, 2, 3, 4]
 
     The graph is correct::
@@ -924,22 +940,22 @@ def GridGraph(dim_list):
 
     Trivial cases::
 
-        sage: g = graphs.GridGraph([]); g; g.vertices()
+        sage: g = graphs.GridGraph([]); g; g.vertices(sort=False)
         Grid Graph for []: Graph on 0 vertices
         []
-        sage: g = graphs.GridGraph([1]); g; g.vertices()
+        sage: g = graphs.GridGraph([1]); g; g.vertices(sort=False)
         Grid Graph for [1]: Graph on 1 vertex
         [0]
-        sage: g = graphs.GridGraph([2]); g; g.vertices()
+        sage: g = graphs.GridGraph([2]); g; g.vertices(sort=True)
         Grid Graph for [2]: Graph on 2 vertices
         [0, 1]
-        sage: g = graphs.GridGraph([1,1]); g; g.vertices()
+        sage: g = graphs.GridGraph([1,1]); g; g.vertices(sort=False)
         Grid Graph for [1, 1]: Graph on 1 vertex
         [(0, 0)]
-        sage: g = graphs.GridGraph([1, 1, 1]); g; g.vertices()
+        sage: g = graphs.GridGraph([1, 1, 1]); g; g.vertices(sort=False)
         Grid Graph for [1, 1, 1]: Graph on 1 vertex
         [(0, 0, 0)]
-        sage: g = graphs.GridGraph([1,1,2]); g; g.vertices()
+        sage: g = graphs.GridGraph([1,1,2]); g; g.vertices(sort=True)
         Grid Graph for [1, 1, 2]: Graph on 2 vertices
         [(0, 0, 0), (0, 0, 1)]
 
@@ -977,6 +993,7 @@ def GridGraph(dim_list):
     g.name("Grid Graph for {}".format(dim))
     return g
 
+
 def HouseGraph():
     """
     Return a house graph with 5 nodes.
@@ -1003,6 +1020,7 @@ def HouseGraph():
     edges = [(0, 1), (0, 2), (1, 3), (2, 3), (2, 4), (3, 4)]
     return Graph(edges, pos=pos_dict, name="House Graph")
 
+
 def HouseXGraph():
     """
     Return a house X graph with 5 nodes.
@@ -1030,6 +1048,7 @@ def HouseXGraph():
     edges = [(0, 1), (0, 2), (0, 3), (1, 2), (1, 3), (2, 3), (2, 4), (3, 4)]
     return Graph(edges, pos=pos_dict, name="House Graph")
 
+
 def LadderGraph(n):
     r"""
     Return a ladder graph with `2 * n` nodes.
@@ -1076,6 +1095,7 @@ def LadderGraph(n):
     G.add_edges((i, i + n) for i in range(n))
     return G
 
+
 def PathGraph(n, pos=None):
     r"""
     Return a path graph with `n` nodes.
@@ -1182,6 +1202,7 @@ def PathGraph(n, pos=None):
     G.add_edges((i, i + 1) for i in range(n - 1))
     return G
 
+
 def StarGraph(n):
     r"""
     Return a star graph with `n + 1` nodes.
