@@ -18,8 +18,11 @@ import sys
 # import from Sage library
 from sage.graphs.graph import Graph
 from sage.misc.randstate import current_randstate
+from sage.misc.randstate import set_random_seed
+from sage.misc.prandom import random
 from sage.misc.prandom import randint
 
+
 def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
     r"""
     Returns a random graph on `n` nodes. Each edge is inserted independently
@@ -31,15 +34,15 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
 
     - ``p`` -- probability of an edge
 
-    - ``seed`` - a ``random.Random`` seed or a Python ``int`` for the random
-      number generator (default: ``None``).
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
 
     - ``fast`` -- boolean set to True (default) to use the algorithm with
       time complexity in `O(n+m)` proposed in [BB2005a]_. It is designed
       for generating large sparse graphs. It is faster than other algorithms for
       *LARGE* instances (try it to know whether it is useful for you).
 
-    - ``algorithm`` -- By default (```algorithm='Sage'``), this function uses the
+    - ``algorithm`` -- By default (``algorithm='Sage'``), this function uses the
       algorithm implemented in ```sage.graphs.graph_generators_pyx.pyx``. When
       ``algorithm='networkx'``, this function calls the NetworkX function
       ``fast_gnp_random_graph``, unless ``fast=False``, then
@@ -60,8 +63,8 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
     probability `p = .4`::
 
         sage: set_random_seed(0)
-        sage: graphs.RandomGNP(6, .4).edges(labels=False)
-        [(0, 1), (0, 5), (1, 2), (2, 4), (3, 4), (3, 5), (4, 5)]
+        sage: graphs.RandomGNP(6, .4).edges(sort=true, labels=False)
+        [(0, 3), (1, 2), (2, 3), (2, 4)]
 
     We plot a random graph on 12 nodes with probability `p = .71`::
 
@@ -95,21 +98,21 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
         sage: graphs.RandomGNP(50,.2, algorithm="Sage").size()
         243
         sage: graphs.RandomGNP(50,.2, algorithm="networkx").size()
-        260     # 32-bit
-        245     # 64-bit
+        279     # 32-bit
+        209     # 64-bit
     """
     if n < 0:
         raise ValueError("The number of nodes must be positive or null.")
     if 0.0 > p or 1.0 < p:
         raise ValueError("The probability p must be in [0..1].")
 
-    if seed is None:
-        seed = int(current_randstate().long_seed() % sys.maxsize)
     if p == 1:
         from sage.graphs.generators.basic import CompleteGraph
         return CompleteGraph(n)
 
     if algorithm == 'networkx':
+        if seed is None:
+            seed = int(current_randstate().long_seed() % sys.maxsize)
         import networkx
         if fast:
             G = networkx.fast_gnp_random_graph(n, p, seed=seed)
@@ -119,10 +122,11 @@ def RandomGNP(n, p, seed=None, fast=True, algorithm='Sage'):
     elif algorithm in ['Sage', 'sage']:
         # We use the Sage generator
         from sage.graphs.graph_generators_pyx import RandomGNP as sageGNP
-        return sageGNP(n, p)
+        return sageGNP(n, p, seed=seed)
     else:
         raise ValueError("'algorithm' must be equal to 'networkx' or to 'Sage'.")
 
+
 def RandomBarabasiAlbert(n, m, seed=None):
     r"""
     Return a random graph created using the Barabasi-Albert preferential
@@ -179,9 +183,10 @@ def RandomBarabasiAlbert(n, m, seed=None):
     if seed is None:
         seed = int(current_randstate().long_seed() % sys.maxsize)
     import networkx
-    return Graph(networkx.barabasi_albert_graph(n, m, seed=seed))
+    return Graph(networkx.barabasi_albert_graph(int(n), int(m), seed=seed))
 
-def RandomBipartite(n1, n2, p, set_position=False):
+
+def RandomBipartite(n1, n2, p, set_position=False, seed=None):
     r"""
     Returns a bipartite graph with `n1+n2` vertices such that any edge
     from `[n1]` to `[n2]` exists with probability `p`.
@@ -196,10 +201,13 @@ def RandomBipartite(n1, n2, p, set_position=False):
       assign positions to the vertices so that the set of cardinality `n1` is
       on the line `y=1` and the set of cardinality `n2` is on the line `y=0`.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     EXAMPLES::
 
         sage: g = graphs.RandomBipartite(5, 2, 0.5)
-        sage: g.vertices()
+        sage: g.vertices(sort=True)
         [(0, 0), (0, 1), (0, 2), (0, 3), (0, 4), (1, 0), (1, 1)]
 
     TESTS::
@@ -233,19 +241,21 @@ def RandomBipartite(n1, n2, p, set_position=False):
         raise ValueError("parameter p is a probability, and so should be a real value between 0 and 1")
     if not (n1 > 0 and n2 > 0):
         raise ValueError("n1 and n2 should be integers strictly greater than 0")
+    if seed is not None:
+        set_random_seed(seed)
 
     from numpy.random import uniform
 
-    g=Graph(name="Random bipartite graph of order "+str(n1) +"+"+str(n2)+" with edge probability "+str(p))
+    g = Graph(name=f"Random bipartite graph of order {n1}+{n2} with edge probability {p}")
 
-    S1 = [(0,i) for i in range(n1)]
-    S2 = [(1,i) for i in range(n2)]
+    S1 = [(0, i) for i in range(n1)]
+    S2 = [(1, i) for i in range(n2)]
     g.add_vertices(S1)
     g.add_vertices(S2)
 
     for w in range(n2):
         for v in range(n1):
-            if uniform() <= p :
+            if uniform() <= p:
                 g.add_edge((0, v), (1, w))
 
     # We now assign positions to vertices:
@@ -259,7 +269,8 @@ def RandomBipartite(n1, n2, p, set_position=False):
 
     return g
 
-def RandomRegularBipartite(n1, n2, d1, set_position=False):
+
+def RandomRegularBipartite(n1, n2, d1, set_position=False, seed=None):
     r"""
     Return a random regular bipartite graph on `n1 + n2` vertices.
 
@@ -284,6 +295,9 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
       assign positions to the vertices so that the set of cardinality `n1` is
       on the line `y=1` and the set of cardinality `n2` is on the line `y=0`.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     EXAMPLES::
 
         sage: g = graphs.RandomRegularBipartite(4, 6, 3)
@@ -324,6 +338,8 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
     d2 = (n1 * d1) // n2
     if n1 * d1 != n2 * d2:
         raise ValueError("the product n1 * d1 must be a multiple of n2")
+    if seed is not None:
+        set_random_seed(seed)
 
     complement = False
     if d1 > n2/2 or d2 > n1/2:
@@ -398,7 +414,7 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
 
     if complement:
         from sage.graphs.generators.basic import CompleteBipartiteGraph
-        E = E.symmetric_difference(CompleteBipartiteGraph(n1, n2).edges(labels=False))
+        E = E.symmetric_difference(CompleteBipartiteGraph(n1, n2).edges(sort=False, labels=False))
         d1, d2 = n2 - d1, n1 - d2
 
     name = "Random regular bipartite graph of order {}+{} and degrees {} and {}".format(n1, n2, d1, d2)
@@ -411,12 +427,12 @@ def RandomRegularBipartite(n1, n2, d1, set_position=False):
     if set_position:
         nmax = max(n1, n2)
         G._line_embedding(list(range(n1)), first=(0, 1), last=(nmax, 1))
-        G._line_embedding(list(range(n1, n1+n2)), first=(0, 0), last=(nmax, 0))
+        G._line_embedding(list(range(n1, n1 + n2)), first=(0, 0), last=(nmax, 0))
 
     return G
 
 
-def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
+def RandomBlockGraph(m, k, kmax=None, incidence_structure=False, seed=None):
     r"""
     Return a Random Block Graph.
 
@@ -447,6 +463,9 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
       graph itself, that is the list of the lists of vertices in each
       block. This is useful for the creation of some hypergraphs.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     OUTPUT:
 
     A Graph when ``incidence_structure==False`` (default), and otherwise an
@@ -532,59 +551,59 @@ def RandomBlockGraph(m, k, kmax=None, incidence_structure=False):
         kmax = k
     elif kmax < k:
         raise ValueError("the maximum number `kmax` of vertices in a block must be >= `k`")
+    if seed is not None:
+        set_random_seed(seed)
 
     if m == 1:
         # A block graph with a single block is a clique
-        IS = [ list(range(randint(k, kmax))) ]
+        IS = [list(range(randint(k, kmax)))]
 
     elif kmax == 2:
         # A block graph with blocks of order 2 is a tree
-        IS = [ list(e) for e in RandomTree(m+1).edges(labels=False) ]
+        IS = [list(e) for e in RandomTree(m + 1).edges(sort=True, labels=False)]
 
     else:
         # We start with a random tree of order m
         T = RandomTree(m)
 
         # We create a block of order in range [k,kmax] per vertex of the tree
-        B = {u:[(u,i) for i in range(randint(k, kmax))] for u in T}
+        B = {u: [(u, i) for i in range(randint(k, kmax))] for u in T}
 
         # For each edge of the tree, we choose 1 vertex in each of the
         # corresponding blocks and we merge them. We use a disjoint set data
         # structure to keep a unique identifier per merged vertices
         DS = DisjointSet([i for u in B for i in B[u]])
-        for u,v in T.edges(labels=0):
+        for u, v in T.edges(sort=True, labels=0):
             DS.union(choice(B[u]), choice(B[v]))
 
         # We relabel vertices in the range [0, m*(k-1)] and build the incidence
         # structure
-        new_label = {root:i for i,root in enumerate(DS.root_to_elements_dict())}
-        IS = [ [new_label[DS.find(v)] for v in B[u]] for u in B ]
+        new_label = {root: i for i, root in enumerate(DS.root_to_elements_dict())}
+        IS = [[new_label[DS.find(v)] for v in B[u]] for u in B]
 
     if incidence_structure:
         return IS
 
     # We finally build the block graph
     if k == kmax:
-        BG = Graph(name = "Random Block Graph with {} blocks of order {}".format(m, k))
+        BG = Graph(name="Random Block Graph with {} blocks of order {}".format(m, k))
     else:
-        BG = Graph(name = "Random Block Graph with {} blocks of order {} to {}".format(m, k, kmax))
+        BG = Graph(name="Random Block Graph with {} blocks of order {} to {}".format(m, k, kmax))
     for block in IS:
-        BG.add_clique( block )
+        BG.add_clique(block)
     return BG
 
 
-def RandomBoundedToleranceGraph(n):
+def RandomBoundedToleranceGraph(n, seed=None):
     r"""
-    Returns a random bounded tolerance graph.
+    Return a random bounded tolerance graph.
 
-    The random tolerance graph is built from a random bounded
-    tolerance representation by using the function
-    `ToleranceGraph`. This representation is a list
-    `((l_0,r_0,t_0), (l_1,r_1,t_1), ..., (l_k,r_k,t_k))` where
-    `k = n-1` and `I_i = (l_i,r_i)` denotes a random interval and
-    `t_i` a random positive value less then or equal to the length
-    of the interval `I_i`. The width of the representation is
-    limited to n**2 * 2**n.
+    The random tolerance graph is built from a random bounded tolerance
+    representation by using the function `ToleranceGraph`. This representation
+    is a list `((l_0,r_0,t_0), (l_1,r_1,t_1), ..., (l_k,r_k,t_k))` where `k =
+    n-1` and `I_i = (l_i,r_i)` denotes a random interval and `t_i` a random
+    positive value less than or equal to the length of the interval `I_i`. The
+    width of the representation is limited to `n^2 * 2^n`.
 
     .. NOTE::
 
@@ -595,6 +614,9 @@ def RandomBoundedToleranceGraph(n):
 
     - ``n`` -- number of vertices of the random graph.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     EXAMPLES:
 
     Every (bounded) tolerance graph is perfect. Hence, the
@@ -609,18 +631,33 @@ def RandomBoundedToleranceGraph(n):
     Check that :trac:`32186` is fixed::
 
         sage: for _ in range(100): _ = graphs.RandomBoundedToleranceGraph(1)
+
+    Check input parameter::
+
+        sage: g = graphs.RandomToleranceGraph(-2)
+        Traceback (most recent call last):
+        ...
+        ValueError: the number `n` of vertices must be >= 0
     """
-    from sage.misc.prandom import randint
-    from sage.combinat.combination import Combinations
+    if n < 0:
+        raise ValueError('the number `n` of vertices must be >= 0')
+    if seed is not None:
+        set_random_seed(seed)
+
     from sage.graphs.generators.intersection import ToleranceGraph
 
     W = n ** 2 * 2 ** n
-    C = Combinations(W + 1, 2)
-
-    tolrep = [(l_r[0], l_r[1], randint(1, l_r[1] - l_r[0])) for l_r in [C.random_element() for i in range(n)]]
+    tolrep = []
+    for _ in range(n):
+        left = randint(0, W - 1)
+        right = randint(0, W)
+        if left >= right:
+            left, right = right, left + 1
+        tolrep.append((left, right, randint(1, right - left)))
 
     return ToleranceGraph(tolrep)
 
+
 def RandomGNM(n, m, dense=False, seed=None):
     """
     Returns a graph randomly picked out of all graphs on n vertices
@@ -635,21 +672,17 @@ def RandomGNM(n, m, dense=False, seed=None):
     - ``dense`` - whether to use NetworkX's
       dense_gnm_random_graph or gnm_random_graph
 
-    - ``seed`` - a ``random.Random`` seed or a Python ``int`` for the random
-      number generator (default: ``None``).
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
 
+    EXAMPLES:
 
-    EXAMPLES: We show the edge list of a random graph on 5 nodes with
-    10 edges.
+    We show the edge list of a random graph on 5 nodes with 10 edges::
 
-    ::
-
-        sage: graphs.RandomGNM(5, 10).edges(labels=False)
+        sage: graphs.RandomGNM(5, 10).edges(sort=True, labels=False)
         [(0, 1), (0, 2), (0, 3), (0, 4), (1, 2), (1, 3), (1, 4), (2, 3), (2, 4), (3, 4)]
 
-    We plot a random graph on 12 nodes with m = 12.
-
-    ::
+    We plot a random graph on 12 nodes with m = 12::
 
         sage: gnm = graphs.RandomGNM(12, 12)
         sage: gnm.show()  # long time
@@ -677,6 +710,7 @@ def RandomGNM(n, m, dense=False, seed=None):
     else:
         return Graph(networkx.gnm_random_graph(n, m, seed=seed))
 
+
 def RandomNewmanWattsStrogatz(n, k, p, seed=None):
     r"""
     Return a Newman-Watts-Strogatz small world random graph on `n` vertices.
@@ -741,6 +775,7 @@ def RandomNewmanWattsStrogatz(n, k, p, seed=None):
     import networkx
     return Graph(networkx.newman_watts_strogatz_graph(n, k, p, seed=seed))
 
+
 def RandomHolmeKim(n, m, p, seed=None):
     r"""
     Return a random graph generated by the Holme and Kim algorithm for
@@ -797,7 +832,7 @@ def RandomHolmeKim(n, m, p, seed=None):
     return Graph(networkx.powerlaw_cluster_graph(n, m, p, seed=seed))
 
 
-def RandomIntervalGraph(n):
+def RandomIntervalGraph(n, seed=None):
     r"""
     Returns a random interval graph.
 
@@ -821,8 +856,10 @@ def RandomIntervalGraph(n):
 
     INPUT:
 
-    - ``n`` (integer) -- the number of vertices in the random
-      graph.
+    - ``n`` -- integer; the number of vertices in the random graph
+
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
 
     EXAMPLES:
 
@@ -833,12 +870,14 @@ def RandomIntervalGraph(n):
         sage: g.clique_number() == g.chromatic_number()
         True
     """
-
+    if seed is not None:
+        set_random_seed(seed)
     from sage.misc.prandom import random
     from sage.graphs.generators.intersection import IntervalGraph
 
     intervals = [tuple(sorted((random(), random()))) for i in range(n)]
-    return IntervalGraph(intervals,True)
+    return IntervalGraph(intervals, True)
+
 
 # Random Chordal Graphs
 
@@ -896,6 +935,7 @@ def growing_subtrees(T, k):
 
     return S
 
+
 def connecting_nodes(T, l):
     r"""
     Return a list of the vertex sets of ``n`` randomly chosen subtrees of ``T``.
@@ -994,6 +1034,7 @@ def connecting_nodes(T, l):
 
     return S
 
+
 def pruned_tree(T, f, s):
     r"""
     Return a list of the vertex sets of ``n`` randomly chosen subtrees of ``T``.
@@ -1074,7 +1115,8 @@ def pruned_tree(T, f, s):
 
     return S
 
-def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None):
+
+def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None, seed=None):
     r"""
     Return a random chordal graph of order ``n``.
 
@@ -1139,6 +1181,9 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None):
       `0.5`. This parameter is used only when ``algorithm="pruned"``.
       See :meth:`~sage.graphs.generators.random.pruned_tree` for more details.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     EXAMPLES::
 
         sage: from sage.graphs.generators.random import RandomChordalGraph
@@ -1190,14 +1235,17 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None):
     if n < 2:
         return Graph(n, name="Random Chordal Graph")
 
+    if seed is not None:
+        set_random_seed(seed)
+
     # 1. Generate a random tree of order n
     T = RandomTree(n)
 
     # 2. Generate n non-empty subtrees of T: {T1,...,Tn}
     if algorithm == "growing":
         if k is None:
-            from sage.rings.integer import Integer
-            k = int(Integer(n).sqrt())
+            from sage.misc.functional import isqrt
+            k = isqrt(n)
         elif k < 1:
             raise ValueError("parameter k must be >= 1")
 
@@ -1230,7 +1278,7 @@ def RandomChordalGraph(n, algorithm="growing", k=None, l=None, f=None, s=None):
 
     # 3. Build the intersection graph of {V(T1),...,V(Tn)}
     vertex_to_subtrees = [[] for _ in range(n)]
-    for i,s in enumerate(S):
+    for i, s in enumerate(S):
         for x in s:
             vertex_to_subtrees[x].append(i)
     G = Graph(n, name="Random Chordal Graph")
@@ -1268,13 +1316,16 @@ def RandomLobster(n, p, q, seed=None):
     nodes and probabilities `p = 0.7` and `q = 0.3`::
 
         sage: G = graphs.RandomLobster(12, 0.7, 0.3)
-        sage: leaves = [v for v in G.vertices() if G.degree(v) == 1]
+        sage: leaves = [v for v in G.vertices(sort=False) if G.degree(v) == 1]
         sage: G.delete_vertices(leaves)                                 # caterpillar
-        sage: leaves = [v for v in G.vertices() if G.degree(v) == 1]
+        sage: leaves = [v for v in G.vertices(sort=False) if G.degree(v) == 1]
         sage: G.delete_vertices(leaves)                                 # path
         sage: s = G.degree_sequence()
         sage: if G:
-        ....:     assert s[-2:] == [1, 1]
+        ....:     if G.num_verts() == 1:
+        ....:         assert s == [0]
+        ....:     else:
+        ....:         assert s[-2:] == [1, 1]
         ....:     assert all(d == 2 for d in s[:-2])
 
     ::
@@ -1288,7 +1339,7 @@ def RandomLobster(n, p, q, seed=None):
     return Graph(networkx.random_lobster(n, p, q, seed=seed))
 
 
-def RandomTree(n):
+def RandomTree(n, seed=None):
     r"""
     Returns a random tree on `n` nodes numbered `0` through `n-1`.
 
@@ -1305,7 +1356,10 @@ def RandomTree(n):
 
     INPUT:
 
-    -  ``n`` - number of vertices in the tree
+    -  ``n`` -- number of vertices in the tree
+
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
 
     EXAMPLES::
 
@@ -1329,16 +1383,18 @@ def RandomTree(n):
         sage: graphs.RandomTree(1)
         Graph on 1 vertex
     """
-    from sage.misc.prandom import randint
     g = Graph(n)
     if n <= 1:
         return g
 
+    if seed is not None:
+        set_random_seed(seed)
+
     # create random Prufer code
-    code = [ randint(0,n-1) for i in range(n-2) ]
+    code = [randint(0, n - 1) for i in range(n - 2)]
 
     # We count the number of symbols of each type.
-    # count[k] is the no. of times k appears in code
+    # count[k] is the number of times k appears in code
     #
     # (count[k] is set to -1 when the corresponding vertex is not
     # available anymore)
@@ -1346,18 +1402,22 @@ def RandomTree(n):
     for k in code:
         count[k] += 1
 
-    for s in code:
-        for x in range(n):
-            if count[x] == 0:
-                break
+    # We use a heap to store vertices for which count[k] == 0 and get the vertex
+    # with smallest index
+    from heapq import heapify, heappop, heappush
+    zeros = [x for x in range(n) if not count[x]]
+    heapify(zeros)
 
+    for s in code:
+        x = heappop(zeros)
+        g.add_edge(x, s)
         count[x] = -1
-        g.add_edge(x,s)
         count[s] -= 1
+        if not count[s]:
+            heappush(zeros, s)
 
     # Adding as an edge the last two available vertices
-    last_edge = [ v for v in range(n) if count[v] != -1 ]
-    g.add_edge(last_edge)
+    g.add_edge(zeros)
 
     return g
 
@@ -1455,6 +1515,7 @@ def RandomRegular(d, n, seed=None):
     except Exception:
         return False
 
+
 def RandomShell(constructor, seed=None):
     """
     Return a random shell graph for the constructor given.
@@ -1485,15 +1546,16 @@ def RandomShell(constructor, seed=None):
     import networkx
     return Graph(networkx.random_shell_graph(constructor, seed=seed))
 
-def RandomToleranceGraph(n):
+
+def RandomToleranceGraph(n, seed=None):
     r"""
-    Returns a random tolerance graph.
+    Return a random tolerance graph.
 
     The random tolerance graph is built from a random tolerance representation
     by using the function `ToleranceGraph`. This representation is a list
     `((l_0,r_0,t_0), (l_1,r_1,t_1), ..., (l_k,r_k,t_k))` where `k = n-1` and
     `I_i = (l_i,r_i)` denotes a random interval and `t_i` a random positive
-    value. The width of the representation is limited to n**2 * 2**n.
+    value. The width of the representation is limited to `n^2 * 2^n`.
 
     .. NOTE::
 
@@ -1503,7 +1565,10 @@ def RandomToleranceGraph(n):
 
     INPUT:
 
-    - ``n`` -- number of vertices of the random graph.
+    - ``n`` -- number of vertices of the random graph
+
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
 
     EXAMPLES:
 
@@ -1519,19 +1584,29 @@ def RandomToleranceGraph(n):
         sage: g = graphs.RandomToleranceGraph(-2)
         Traceback (most recent call last):
         ...
-        ValueError: The number `n` of vertices must be >= 0.
+        ValueError: the number `n` of vertices must be >= 0
     """
-    from sage.misc.prandom import randint
     from sage.graphs.generators.intersection import ToleranceGraph
 
-    if n<0:
-        raise ValueError('The number `n` of vertices must be >= 0.')
+    if n < 0:
+        raise ValueError('the number `n` of vertices must be >= 0')
+    if seed is not None:
+        set_random_seed(seed)
 
     W = n**2 * 2**n
 
-    tolrep = [tuple(sorted((randint(0,W), randint(0,W)))) + (randint(0,W),) for i in range(n)]
+    tolrep = []
+    for _ in range(n):
+        left = randint(0, W)
+        right = randint(0, W)
+        if left > right:
+            left, right = right, left
+        # The tolerance value must be > 0
+        tolrep.append((left, right, randint(1, W)))
 
-    return ToleranceGraph(tolrep)
+    g = ToleranceGraph(tolrep)
+    g.name("Random tolerance graph")
+    return g
 
 
 # uniform random triangulation using Schaeffer-Poulalhon algorithm
@@ -1695,14 +1770,14 @@ def _contour_and_graph_from_words(pendant_word, forest_word):
          7: [6],
          8: [6]}
     """
-    k = (len(pendant_word)+4) // 2
+    k = (len(pendant_word) + 4) // 2
 
-    index = 0 # numbering of inner vertices
-    word = [('in',0)] # the word representing the contour walk
+    index = 0  # numbering of inner vertices
+    word = [('in', 0)]  # the word representing the contour walk
 
     # start with the outer face, a cycle of length k
-    edges = [[i, (i+1) % k] for i in range(k)]
-    embedding = {i: [(i+1) % k, (i-1+k) % k] for i in range(k)}
+    edges = [[i, (i + 1) % k] for i in range(k)]
+    embedding = {i: [(i + 1) % k, (i - 1 + k) % k] for i in range(k)}
 
     # add the pendant edges
     for x in pendant_word:
@@ -1764,7 +1839,8 @@ def _contour_and_graph_from_words(pendant_word, forest_word):
     G.set_embedding(embedding)
     return word, G
 
-def RandomTriangulation(n, set_position=False, k=3):
+
+def RandomTriangulation(n, set_position=False, k=3, seed=None):
     r"""
     Return a random inner triangulation of an outer face of degree ``k`` with
     ``n`` vertices in total.
@@ -1781,6 +1857,9 @@ def RandomTriangulation(n, set_position=False, k=3):
     - ``set_position`` -- boolean (default ``False``); if set to ``True``, this
       will compute coordinates for a planar drawing of the graph.
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     OUTPUT:
 
     A random graph chosen uniformly among the inner triangulations of a *rooted*
@@ -1855,6 +1934,8 @@ def RandomTriangulation(n, set_position=False, k=3):
     if n < k:
         raise ValueError("The number 'n' of vertices must be at least the size "
                          "'k' of the outer face.")
+    if seed is not None:
+        set_random_seed(seed)
 
     from sage.misc.prandom import shuffle
     pendant_word = [0] * (k-1) + [1] * (k-3)
@@ -1864,7 +1945,7 @@ def RandomTriangulation(n, set_position=False, k=3):
     edges = []
     embedding = graph.get_embedding()
 
-    pattern = ['in', 'in', 'in', 'lf', 'in'] # 'partial closures'
+    pattern = ['in', 'in', 'in', 'lf', 'in']  # 'partial closures'
 
     def rotate_word_to_next_occurrence(word):
         """
@@ -1902,7 +1983,7 @@ def RandomTriangulation(n, set_position=False, k=3):
     return graph
 
 
-def blossoming_contour(t, shift=0):
+def blossoming_contour(t, shift=0, seed=None):
     """
     Return a random blossoming of a binary tree `t`, as a contour word.
 
@@ -1958,6 +2039,9 @@ def blossoming_contour(t, shift=0):
     """
     if not t:
         raise ValueError('tree must be non-empty')
+    if seed is not None:
+        set_random_seed(seed)
+
     t1, t2 = t
     leaf_xb = ('xb',)
     leaf_x = ('x',)
@@ -1992,7 +2076,7 @@ def blossoming_contour(t, shift=0):
     return label + tt1 + label + tt2 + label
 
 
-def RandomBicubicPlanar(n):
+def RandomBicubicPlanar(n, seed=None):
     """
     Return the graph of a random bipartite cubic map with `3 n` edges.
 
@@ -2000,6 +2084,9 @@ def RandomBicubicPlanar(n):
 
     `n` -- an integer (at least `1`)
 
+    - ``seed`` -- a ``random.Random`` seed or a Python ``int`` for the random
+      number generator (default: ``None``)
+
     OUTPUT:
 
     a graph with multiple edges (no embedding is provided)
@@ -2031,8 +2118,8 @@ def RandomBicubicPlanar(n):
         True
         sage: G.is_bipartite() and G.is_planar() and G.is_regular(3)
         True
-        sage: dic = {'red':[v for v in G.vertices() if v[0] == 'n'],
-        ....:        'blue': [v for v in G.vertices() if v[0] != 'n']}
+        sage: dic = {'red':[v for v in G.vertices(sort=False) if v[0] == 'n'],
+        ....:        'blue': [v for v in G.vertices(sort=False) if v[0] != 'n']}
         sage: G.plot(vertex_labels=False,vertex_size=20,vertex_colors=dic)
         Graphics object consisting of ... graphics primitives
 
@@ -2040,8 +2127,8 @@ def RandomBicubicPlanar(n):
         :width: 300 px
 
         G = graphs.RandomBicubicPlanar(200)
-        V0 = [v for v in G.vertices() if v[0] == 'n']
-        V1 = [v for v in G.vertices() if v[0] != 'n']
+        V0 = [v for v in G.vertices(sort=False) if v[0] == 'n']
+        V1 = [v for v in G.vertices(sort=False) if v[0] != 'n']
         dic = {'red': V0, 'blue': V1}
         sphinx_plot(G.plot(vertex_labels=False,vertex_colors=dic))
     """
@@ -2049,6 +2136,9 @@ def RandomBicubicPlanar(n):
     from sage.rings.finite_rings.integer_mod_ring import Zmod
     if not n:
         raise ValueError("n must be at least 1")
+    if seed is not None:
+        set_random_seed(seed)
+
     # first pick a random binary tree
     t = BinaryTrees(n).random_element()
 
@@ -2105,3 +2195,59 @@ def RandomBicubicPlanar(n):
         G.add_edge((('n', -1), w[i - 1], colour))
 
     return G
+
+
+def RandomUnitDiskGraph(n, radius=.1, side=1, seed=None):
+    r"""
+    Return a random unit disk graph of order `n`.
+
+    A unit disk graph is the intersection graph of a family of unit disks in the
+    Euclidean plane. That is a graph with one vertex per disk of the family and
+    an edge between two vertices whenever they lie within a unit distance of
+    each other. See the :wikipedia:`Unit_disk_graph` for more details.
+
+    INPUT:
+
+    - ``n`` -- number of nodes
+
+    - ``radius`` -- float (default: ``0.1``); two vertices at distance less than
+      ``radius`` are connected by an edge
+
+    - ``side`` -- float (default: ``1``); indicate the side of the area in which
+      the points are drawn
+
+    - ``seed`` -- seed of the random number generator
+
+    EXAMPLES:
+
+    When using twice the same seed, the vertices get the same positions::
+
+        sage: from sage.misc.randstate import current_randstate
+        sage: seed = current_randstate().seed()
+        sage: G = graphs.RandomUnitDiskGraph(20, radius=.5, side=1, seed=seed)
+        sage: H = graphs.RandomUnitDiskGraph(20, radius=.2, side=1, seed=seed)
+        sage: H.is_subgraph(G, induced=False)
+        True
+        sage: H.size() <= G.size()
+        True
+        sage: Gpos = G.get_pos()
+        sage: Hpos = H.get_pos()
+        sage: all(Gpos[u] == Hpos[u] for u in G)
+        True
+
+    When the radius is more than `\sqrt{2 \text{side}}`, the graph is a clique::
+
+        sage: G = graphs.RandomUnitDiskGraph(10, radius=2, side=1)
+        sage: G.is_clique()
+        True
+    """
+    if seed is not None:
+        set_random_seed(seed)
+    from scipy.spatial import KDTree
+    points = [(side*random(), side*random()) for i in range(n)]
+    T = KDTree(points)
+    adj = {i: [u for u in T.query_ball_point([points[i]], radius).item() if u != i]
+           for i in range(n)}
+    return Graph(adj, format='dict_of_lists',
+                 pos={i: points[i] for i in range(n)},
+                 name="Random unit disk graph")
